Moved title syntax to a separate file so that it improves code readability
and allows for easy addition of new correct title syntax in future cases.

Signed-off-by: Sean Morrissey <sean.morris...@intel.com>
---
 devtools/check-git-log.sh        | 60 ++++++++------------------------
 devtools/commit-title-syntax.txt | 45 ++++++++++++++++++++++++
 2 files changed, 60 insertions(+), 45 deletions(-)
 create mode 100644 devtools/commit-title-syntax.txt

diff --git a/devtools/commit-title-syntax.txt b/devtools/commit-title-syntax.txt
new file mode 100644
index 000000000..0d4b9af01
--- /dev/null
+++ b/devtools/commit-title-syntax.txt
@@ -0,0 +1,45 @@
+Rx
+Tx
+PF
+VF
+HW
+SW
+FW
+L2
+L3
+L4
+API
+arm
+aarch64
+armv7
+armv8
+CRC
+DCB
+DMA
+EEPROM
+FreeBSD
+IOVA
+LACP
+Linux
+LRO
+LSC
+MAC
+MSS
+MTU
+NIC
+NVM
+NUMA
+PCI
+PHY
+PMD
+RETA
+RSS
+SCTP
+TOS
+TPID
+TSO
+TTL
+UDP
+VLAN
+VDPA
+VSI
diff --git a/devtools/check-git-log.sh b/devtools/check-git-log.sh
index a763ccf78..4152f6dfa 100755
--- a/devtools/check-git-log.sh
+++ b/devtools/check-git-log.sh
@@ -83,51 +83,21 @@ bad=$(echo "$headlines" | grep --color=always \
        | sed 's,^,\t,')
 [ -z "$bad" ] || printf "Wrong headline uppercase:\n$bad\n"
 
-# check headline uppercase (Rx/Tx, VF, L2, MAC, Linux, ARM...)
-bad=$(echo "$headlines" | grep -E --color=always \
-       -e ':.*\<(rx|tx|RX|TX)\>' \
-       -e ':.*\<[pv]f\>' \
-       -e ':.*\<[hsf]w\>' \
-       -e ':.*\<l[234]\>' \
-       -e ':.*\<api\>' \
-       -e ':.*\<ARM\>' \
-       -e ':.*\<(Aarch64|AArch64|AARCH64|Aarch32|AArch32|AARCH32)\>' \
-       -e ':.*\<(Armv7|ARMv7|ArmV7|armV7|ARMV7)\>' \
-       -e ':.*\<(Armv8|ARMv8|ArmV8|armV8|ARMV8)\>' \
-       -e ':.*\<crc\>' \
-       -e ':.*\<dcb\>' \
-       -e ':.*\<dma\>' \
-       -e ':.*\<eeprom\>' \
-       -e ':.*\<freebsd\>' \
-       -e ':.*\<iova\>' \
-       -e ':.*\<lacp\>' \
-       -e ':.*\<linux\>' \
-       -e ':.*\<lro\>' \
-       -e ':.*\<lsc\>' \
-       -e ':.*\<mac\>' \
-       -e ':.*\<mss\>' \
-       -e ':.*\<mtu\>' \
-       -e ':.*\<nic\>' \
-       -e ':.*\<nvm\>' \
-       -e ':.*\<numa\>' \
-       -e ':.*\<pci\>' \
-       -e ':.*\<phy\>' \
-       -e ':.*\<pmd\>' \
-       -e ':.*\<reta\>' \
-       -e ':.*\<rss\>' \
-       -e ':.*\<sctp\>' \
-       -e ':.*\<tos\>' \
-       -e ':.*\<tpid\>' \
-       -e ':.*\<tso\>' \
-       -e ':.*\<ttl\>' \
-       -e ':.*\<udp\>' \
-       -e ':.*\<[Vv]lan\>' \
-       -e ':.*\<vdpa\>' \
-       -e ':.*\<vsi\>' \
-       | grep \
-       -v ':.*\<OCTEON\ TX\>' \
-       | sed 's,^,\t,')
-[ -z "$bad" ] || printf "Wrong headline lowercase:\n$bad\n"
+# check headline case (Rx/Tx, VF, L2, MAC, Linux ...)
+data="$selfdir/commit-title-syntax.txt"
+while IFS= read -r line
+do
+       regex=":.*\<$line\>"
+       bad=$(echo "$headlines" | grep -i $regex | grep \
+               -v ':.*\<OCTEON\ TX\>' )
+       if ! [ -z "$bad" ]
+       then
+               bad=$(echo "$headlines" | grep --color=always -v $regex \
+                       | grep --color=always -i $regex \
+                       | sed 's,^,\t,')
+               [ -z "$bad" ] || printf "Wrong headline case:\n$bad\n"
+       fi
+done < "$data"
 
 # special case check for VMDq to give good error message
 bad=$(echo "$headlines" | grep -E --color=always \
-- 
2.17.1

Reply via email to